from decimal import Decimal

from src.core.util import (get_first_day_by_str, get_first_day_of_last_month,
                           get_last_day_of_last_month)
from src.entity.database import db
from src.entity.finance import get_finance
from src.entity.user import User


def calculate_commission(profit, employee_type, target_completion):
    # 定义提成点位
    commission_rates = {
        "1": [(0, 0.03), (100001, 0.08), (300001, 0.10), (500001, 0.11), (700001, 0.12), (1000001, 0.13)],
        "2": [(0, 0.02), (100001, 0.05), (300001, 0.07), (500001, 0.08), (700001, 0.09), (1000001, 0.10)],
        "3": [(0, 0.02), (100001, 0.03), (300001, 0.04), (500001, 0.05), (700001, 0.06), (1000001, 0.07)]
    }

    # 根据负盈利选择正确的提成点位
    rates = commission_rates[employee_type]
    rate = 0
    for r in rates:
        if profit >= r[0]:
            rate = r[1]
        else:
            break

    # 计算提成
    commission = profit * target_completion * Decimal(str(rate))
    return commission


def calculate_salary(employee_type, agent_profit):
    if employee_type == "3":
        base_salary = 30000
    else:
        base_salary = 12000
    total_salary = 0
    for profit in agent_profit:
        total_salary += calculate_commission(profit, employee_type, 1)
    if total_salary > 70000:
        base_salary = 0
    return total_salary + base_salary


def get_salary(user: User, date: str):
    profits = []
    start_date = get_first_day_by_str(date)
    for account in user.accounts:
        finance = get_finance(account, start_date, date)
        print(f'{finance.name}: {finance.netProfit}')
        profits.append(int(float(finance.netProfit)))
    return f'方式一：{calculate_salary("1", profits)}\n方式二：{calculate_salary("2", profits)}\n方式三：{calculate_salary("3", profits)}'


def get_last_month_salary(user: User):
    profits = []
    for account in user.accounts:
        finance = get_finance(account, get_first_day_of_last_month(), get_last_day_of_last_month())
        print(f'{finance.name}: {finance.netProfit}')
        profits.append(int(float(finance.netProfit)))
    return f'方式一：{calculate_salary("1", profits)}\n方式二：{calculate_salary("2", profits)}\n方式三：{calculate_salary("3", profits)}'

