from concurrent.futures import ThreadPoolExecutor
from typing import List

import pyperclip

from src import logger
from src.core import util
from src.entity.database import db
from src.entity.finance import Finance, get_finance
from src.entity.user import User
from src.entity.visual_list import VisualInfo, get_curr_data, get_visual_list


def get_statics(account, date=util.get_curr_day()) -> VisualInfo:
    params = {"monthDate": util.get_curr_month()}
    data = get_visual_list(account, params)
    # 合并列表并创建日期到数据的映射
    date_map = {item.staticsDate: item for item in data.curData + data.lastData}

    # 直接通过日期获取数据
    return date_map.get(date)


def count_by_user(user: User, date: str):
    accounts = user.accounts
    with ThreadPoolExecutor(max_workers=len(accounts)) as t:
        futures = [t.submit(get_statics, account, date) for account in accounts]
        return [future.result() for future in futures]


def text_count_by_user(user: User, date: str) -> str:
    visual_list = count_by_user(user, date)
    text = '\n\n'.join(
        f'{result.agentName}\n注册：{result.isNew}\n首存：{result.firstCount}\n日活：{int(result.countBets)}\n流水：{int(result.bets)}'
        for result in visual_list
    )
    logger.info(f'Generated text: {text}')
    return text


def get_finances_by_user(user: User, date) -> List[Finance]:
    accounts = user.accounts
    start_date = util.get_first_day_by_str(date)
    with ThreadPoolExecutor(max_workers=len(accounts)) as t:
        futures = [t.submit(get_finance, account, start_date, date) for account in accounts]
        return [future.result() for future in futures]


def get_net_win(user: User, date: str) -> str:
    finances = get_finances_by_user(user, date)
    finance_strings = [f"{finance.name}: {finance.netProfit}" for finance in finances]
    logger.info(f'Finance strings: {finance_strings}')
    return '\n'.join(finance_strings)
