from dataclasses import dataclass
from decimal import Decimal

from src.core import util
from src.core.api_request import account_post
from src.core.constant import FINANCE_URL
from src.entity.account import Account

'''
财务报表
'''


@dataclass
class Finance(object):
    profit: Decimal
    promo: Decimal
    thirdPartySpend: Decimal
    netProfit: Decimal
    deposit: Decimal
    draw: Decimal
    rebate: Decimal
    adjust: Decimal
    netAmount: Decimal
    betAmount: Decimal
    handlingFee: Decimal
    partnershipProfit: Decimal
    name: str

    def __init__(self, **kwargs):
        for key, value in kwargs.items():
            if value is not None:
                setattr(self, key, value)


def get_finance(account: Account, start_date=util.get_first_day_month(), end_date=util.get_curr_day()) -> Finance:
    """
    :rtype: Finance
    """
    api_response = account_post(url=FINANCE_URL, account=account, params={
        "startDate": start_date,
        "endDate": end_date,
        "topId": 0
    })
    finance = Finance(**api_response.data)
    finance.name = account.name
    return finance
