import json
from dataclasses import dataclass

from src.core import api_request
from src.core.constant import VISUAL_LIST_URL
from src.entity.account import Account


# 视图列表对象 对应界面上的图表
@dataclass
class VisualInfo:
    staticsDate: str
    agentId: int
    agentType: int
    agentCode: str
    agentName: str
    isNew: int
    firstDeposit: float
    deposit: float
    depositPromo: float
    draw: int
    promo: float
    promoDividend: float
    rebate: float
    adjust: float
    riskAdjust: float
    bets: float
    profit: float
    allBets: float
    firstCount: int
    countDeposit: int
    countDraw: int
    countBets: int
    createdAt: str
    updatedAt: str
    oldDeposit: float
    oldDepositCount: int
    newDeposit: float

    @staticmethod
    def from_dict(data):
        return VisualInfo(**data)


@dataclass
class VisualList:
    curData: list[VisualInfo]
    lastData: list[VisualInfo]

    @staticmethod
    def from_json(json_str):
        data = json.loads(json_str)
        cur_data = [VisualInfo.from_dict(item) for item in data['curData']]
        last_data = [VisualInfo.from_dict(item) for item in data['lastData']]
        return VisualList(curData=cur_data, lastData=last_data)

    @staticmethod
    def dict_to_visual_list(data):
        cur_data = [VisualInfo(**item) for item in data['curData']]
        last_data = [VisualInfo(**item) for item in data['lastData']]
        return VisualList(curData=cur_data, lastData=last_data)


def get_visual_list(account: Account, params: dict) -> VisualList:
    res = api_request.account_post(url=VISUAL_LIST_URL, account=account,
                                   params=params)
    return VisualList.dict_to_visual_list(res.data)


def get_curr_data(account: Account, params: dict) -> list[VisualInfo]:
    res = api_request.account_post(url=VISUAL_LIST_URL, account=account,
                                   params=params)
    return [VisualInfo(**item) for item in res.data['curData']]


async def async_get_visual_list(account: Account, params: dict) -> VisualList:
    res = await api_request.async_account_post(url=VISUAL_LIST_URL, account=account,
                                               params=params)
    return VisualList(**res.data)


async def async_get_curr_data(account: Account, params: dict) -> list[VisualInfo]:
    res = await api_request.async_account_post(url=VISUAL_LIST_URL, account=account,
                                               params=params)
    return [VisualInfo(**item) for item in res.data['curData']]
